# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data
import json

class GenerateWebofficeTokenRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2020-09-30', 'GenerateWebofficeToken','imm')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Referer(self): # String
		return self.get_query_params().get('Referer')

	def set_Referer(self, Referer):  # String
		self.add_query_param('Referer', Referer)
	def get_Notification(self): # Struct
		return self.get_query_params().get('Notification')

	def set_Notification(self, Notification):  # Struct
		self.add_query_param("Notification", json.dumps(Notification))
	def get_Password(self): # String
		return self.get_query_params().get('Password')

	def set_Password(self, Password):  # String
		self.add_query_param('Password', Password)
	def get_ProjectName(self): # String
		return self.get_query_params().get('ProjectName')

	def set_ProjectName(self, ProjectName):  # String
		self.add_query_param('ProjectName', ProjectName)
	def get_Watermark(self): # Struct
		return self.get_query_params().get('Watermark')

	def set_Watermark(self, Watermark):  # Struct
		self.add_query_param("Watermark", json.dumps(Watermark))
	def get_NotifyTopicName(self): # String
		return self.get_query_params().get('NotifyTopicName')

	def set_NotifyTopicName(self, NotifyTopicName):  # String
		self.add_query_param('NotifyTopicName', NotifyTopicName)
	def get_Filename(self): # String
		return self.get_query_params().get('Filename')

	def set_Filename(self, Filename):  # String
		self.add_query_param('Filename', Filename)
	def get_SourceURI(self): # String
		return self.get_query_params().get('SourceURI')

	def set_SourceURI(self, SourceURI):  # String
		self.add_query_param('SourceURI', SourceURI)
	def get_ExternalUploaded(self): # Boolean
		return self.get_query_params().get('ExternalUploaded')

	def set_ExternalUploaded(self, ExternalUploaded):  # Boolean
		self.add_query_param('ExternalUploaded', ExternalUploaded)
	def get_UserData(self): # String
		return self.get_query_params().get('UserData')

	def set_UserData(self, UserData):  # String
		self.add_query_param('UserData', UserData)
	def get_PreviewPages(self): # Long
		return self.get_query_params().get('PreviewPages')

	def set_PreviewPages(self, PreviewPages):  # Long
		self.add_query_param('PreviewPages', PreviewPages)
	def get_Hidecmb(self): # Boolean
		return self.get_query_params().get('Hidecmb')

	def set_Hidecmb(self, Hidecmb):  # Boolean
		self.add_query_param('Hidecmb', Hidecmb)
	def get_CachePreview(self): # Boolean
		return self.get_query_params().get('CachePreview')

	def set_CachePreview(self, CachePreview):  # Boolean
		self.add_query_param('CachePreview', CachePreview)
	def get_Permission(self): # Struct
		return self.get_query_params().get('Permission')

	def set_Permission(self, Permission):  # Struct
		self.add_query_param("Permission", json.dumps(Permission))
	def get_CredentialConfig(self): # Struct
		return self.get_query_params().get('CredentialConfig')

	def set_CredentialConfig(self, CredentialConfig):  # Struct
		self.add_query_param("CredentialConfig", json.dumps(CredentialConfig))
	def get_User(self): # Struct
		return self.get_query_params().get('User')

	def set_User(self, User):  # Struct
		self.add_query_param("User", json.dumps(User))



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data

class UpdateProjectRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2020-09-30', 'UpdateProject','imm')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_DatasetMaxBindCount(self): # Long
		return self.get_query_params().get('DatasetMaxBindCount')

	def set_DatasetMaxBindCount(self, DatasetMaxBindCount):  # Long
		self.add_query_param('DatasetMaxBindCount', DatasetMaxBindCount)
	def get_Description(self): # String
		return self.get_query_params().get('Description')

	def set_Description(self, Description):  # String
		self.add_query_param('Description', Description)
	def get_DatasetMaxRelationCount(self): # Long
		return self.get_query_params().get('DatasetMaxRelationCount')

	def set_DatasetMaxRelationCount(self, DatasetMaxRelationCount):  # Long
		self.add_query_param('DatasetMaxRelationCount', DatasetMaxRelationCount)
	def get_DatasetMaxFileCount(self): # Long
		return self.get_query_params().get('DatasetMaxFileCount')

	def set_DatasetMaxFileCount(self, DatasetMaxFileCount):  # Long
		self.add_query_param('DatasetMaxFileCount', DatasetMaxFileCount)
	def get_ProjectName(self): # String
		return self.get_query_params().get('ProjectName')

	def set_ProjectName(self, ProjectName):  # String
		self.add_query_param('ProjectName', ProjectName)
	def get_ProjectMaxDatasetCount(self): # Long
		return self.get_query_params().get('ProjectMaxDatasetCount')

	def set_ProjectMaxDatasetCount(self, ProjectMaxDatasetCount):  # Long
		self.add_query_param('ProjectMaxDatasetCount', ProjectMaxDatasetCount)
	def get_DatasetMaxEntityCount(self): # Long
		return self.get_query_params().get('DatasetMaxEntityCount')

	def set_DatasetMaxEntityCount(self, DatasetMaxEntityCount):  # Long
		self.add_query_param('DatasetMaxEntityCount', DatasetMaxEntityCount)
	def get_TemplateId(self): # String
		return self.get_query_params().get('TemplateId')

	def set_TemplateId(self, TemplateId):  # String
		self.add_query_param('TemplateId', TemplateId)
	def get_DatasetMaxTotalFileSize(self): # Long
		return self.get_query_params().get('DatasetMaxTotalFileSize')

	def set_DatasetMaxTotalFileSize(self, DatasetMaxTotalFileSize):  # Long
		self.add_query_param('DatasetMaxTotalFileSize', DatasetMaxTotalFileSize)
	def get_ServiceRole(self): # String
		return self.get_query_params().get('ServiceRole')

	def set_ServiceRole(self, ServiceRole):  # String
		self.add_query_param('ServiceRole', ServiceRole)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data
import json

class QueryLocationDateClustersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2020-09-30', 'QueryLocationDateClusters','imm')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CustomLabels(self): # String
		return self.get_query_params().get('CustomLabels')

	def set_CustomLabels(self, CustomLabels):  # String
		self.add_query_param('CustomLabels', CustomLabels)
	def get_Order(self): # String
		return self.get_query_params().get('Order')

	def set_Order(self, Order):  # String
		self.add_query_param('Order', Order)
	def get_ProjectName(self): # String
		return self.get_query_params().get('ProjectName')

	def set_ProjectName(self, ProjectName):  # String
		self.add_query_param('ProjectName', ProjectName)
	def get_LocationDateClusterLevels(self): # Array
		return self.get_query_params().get('LocationDateClusterLevels')

	def set_LocationDateClusterLevels(self, LocationDateClusterLevels):  # Array
		self.add_query_param("LocationDateClusterLevels", json.dumps(LocationDateClusterLevels))
	def get_Sort(self): # String
		return self.get_query_params().get('Sort')

	def set_Sort(self, Sort):  # String
		self.add_query_param('Sort', Sort)
	def get_MaxResults(self): # Integer
		return self.get_query_params().get('MaxResults')

	def set_MaxResults(self, MaxResults):  # Integer
		self.add_query_param('MaxResults', MaxResults)
	def get_LocationDateClusterEndTimeRange(self): # Struct
		return self.get_query_params().get('LocationDateClusterEndTimeRange')

	def set_LocationDateClusterEndTimeRange(self, LocationDateClusterEndTimeRange):  # Struct
		self.add_query_param("LocationDateClusterEndTimeRange", json.dumps(LocationDateClusterEndTimeRange))
	def get_Title(self): # String
		return self.get_query_params().get('Title')

	def set_Title(self, Title):  # String
		self.add_query_param('Title', Title)
	def get_NextToken(self): # String
		return self.get_query_params().get('NextToken')

	def set_NextToken(self, NextToken):  # String
		self.add_query_param('NextToken', NextToken)
	def get_DatasetName(self): # String
		return self.get_query_params().get('DatasetName')

	def set_DatasetName(self, DatasetName):  # String
		self.add_query_param('DatasetName', DatasetName)
	def get_LocationDateClusterStartTimeRange(self): # Struct
		return self.get_query_params().get('LocationDateClusterStartTimeRange')

	def set_LocationDateClusterStartTimeRange(self, LocationDateClusterStartTimeRange):  # Struct
		self.add_query_param("LocationDateClusterStartTimeRange", json.dumps(LocationDateClusterStartTimeRange))
	def get_Address(self): # Struct
		return self.get_query_params().get('Address')

	def set_Address(self, Address):  # Struct
		self.add_query_param("Address", json.dumps(Address))
	def get_CreateTimeRange(self): # Struct
		return self.get_query_params().get('CreateTimeRange')

	def set_CreateTimeRange(self, CreateTimeRange):  # Struct
		self.add_query_param("CreateTimeRange", json.dumps(CreateTimeRange))
	def get_UpdateTimeRange(self): # Struct
		return self.get_query_params().get('UpdateTimeRange')

	def set_UpdateTimeRange(self, UpdateTimeRange):  # Struct
		self.add_query_param("UpdateTimeRange", json.dumps(UpdateTimeRange))
	def get_ObjectId(self): # String
		return self.get_query_params().get('ObjectId')

	def set_ObjectId(self, ObjectId):  # String
		self.add_query_param('ObjectId', ObjectId)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data
import json

class CreateOfficeConversionTaskRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2020-09-30', 'CreateOfficeConversionTask','imm')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_SheetCount(self): # Long
		return self.get_query_params().get('SheetCount')

	def set_SheetCount(self, SheetCount):  # Long
		self.add_query_param('SheetCount', SheetCount)
	def get_ShowComments(self): # Boolean
		return self.get_query_params().get('ShowComments')

	def set_ShowComments(self, ShowComments):  # Boolean
		self.add_query_param('ShowComments', ShowComments)
	def get_Notification(self): # Struct
		return self.get_query_params().get('Notification')

	def set_Notification(self, Notification):  # Struct
		self.add_query_param("Notification", json.dumps(Notification))
	def get_Password(self): # String
		return self.get_query_params().get('Password')

	def set_Password(self, Password):  # String
		self.add_query_param('Password', Password)
	def get_Pages(self): # String
		return self.get_query_params().get('Pages')

	def set_Pages(self, Pages):  # String
		self.add_query_param('Pages', Pages)
	def get_SourceType(self): # String
		return self.get_query_params().get('SourceType')

	def set_SourceType(self, SourceType):  # String
		self.add_query_param('SourceType', SourceType)
	def get_ProjectName(self): # String
		return self.get_query_params().get('ProjectName')

	def set_ProjectName(self, ProjectName):  # String
		self.add_query_param('ProjectName', ProjectName)
	def get_FitToHeight(self): # Boolean
		return self.get_query_params().get('FitToHeight')

	def set_FitToHeight(self, FitToHeight):  # Boolean
		self.add_query_param('FitToHeight', FitToHeight)
	def get_EndPage(self): # Long
		return self.get_query_params().get('EndPage')

	def set_EndPage(self, EndPage):  # Long
		self.add_query_param('EndPage', EndPage)
	def get_FitToWidth(self): # Boolean
		return self.get_query_params().get('FitToWidth')

	def set_FitToWidth(self, FitToWidth):  # Boolean
		self.add_query_param('FitToWidth', FitToWidth)
	def get_Quality(self): # Long
		return self.get_query_params().get('Quality')

	def set_Quality(self, Quality):  # Long
		self.add_query_param('Quality', Quality)
	def get_Tags(self): # Map
		return self.get_query_params().get('Tags')

	def set_Tags(self, Tags):  # Map
		self.add_query_param("Tags", json.dumps(Tags))
	def get_SourceURI(self): # String
		return self.get_query_params().get('SourceURI')

	def set_SourceURI(self, SourceURI):  # String
		self.add_query_param('SourceURI', SourceURI)
	def get_SheetIndex(self): # Long
		return self.get_query_params().get('SheetIndex')

	def set_SheetIndex(self, SheetIndex):  # Long
		self.add_query_param('SheetIndex', SheetIndex)
	def get_HoldLineFeed(self): # Boolean
		return self.get_query_params().get('HoldLineFeed')

	def set_HoldLineFeed(self, HoldLineFeed):  # Boolean
		self.add_query_param('HoldLineFeed', HoldLineFeed)
	def get_LongText(self): # Boolean
		return self.get_query_params().get('LongText')

	def set_LongText(self, LongText):  # Boolean
		self.add_query_param('LongText', LongText)
	def get_TargetType(self): # String
		return self.get_query_params().get('TargetType')

	def set_TargetType(self, TargetType):  # String
		self.add_query_param('TargetType', TargetType)
	def get_TrimPolicy(self): # Struct
		return self.get_query_params().get('TrimPolicy')

	def set_TrimPolicy(self, TrimPolicy):  # Struct
		self.add_query_param("TrimPolicy", json.dumps(TrimPolicy))
	def get_MaxSheetColumn(self): # Long
		return self.get_query_params().get('MaxSheetColumn')

	def set_MaxSheetColumn(self, MaxSheetColumn):  # Long
		self.add_query_param('MaxSheetColumn', MaxSheetColumn)
	def get_FirstPage(self): # Boolean
		return self.get_query_params().get('FirstPage')

	def set_FirstPage(self, FirstPage):  # Boolean
		self.add_query_param('FirstPage', FirstPage)
	def get_PaperHorizontal(self): # Boolean
		return self.get_query_params().get('PaperHorizontal')

	def set_PaperHorizontal(self, PaperHorizontal):  # Boolean
		self.add_query_param('PaperHorizontal', PaperHorizontal)
	def get_UserData(self): # String
		return self.get_query_params().get('UserData')

	def set_UserData(self, UserData):  # String
		self.add_query_param('UserData', UserData)
	def get_ScalePercentage(self): # Long
		return self.get_query_params().get('ScalePercentage')

	def set_ScalePercentage(self, ScalePercentage):  # Long
		self.add_query_param('ScalePercentage', ScalePercentage)
	def get_StartPage(self): # Long
		return self.get_query_params().get('StartPage')

	def set_StartPage(self, StartPage):  # Long
		self.add_query_param('StartPage', StartPage)
	def get_TargetURIPrefix(self): # String
		return self.get_query_params().get('TargetURIPrefix')

	def set_TargetURIPrefix(self, TargetURIPrefix):  # String
		self.add_query_param('TargetURIPrefix', TargetURIPrefix)
	def get_TargetURI(self): # String
		return self.get_query_params().get('TargetURI')

	def set_TargetURI(self, TargetURI):  # String
		self.add_query_param('TargetURI', TargetURI)
	def get_PaperSize(self): # String
		return self.get_query_params().get('PaperSize')

	def set_PaperSize(self, PaperSize):  # String
		self.add_query_param('PaperSize', PaperSize)
	def get_ImageDPI(self): # Long
		return self.get_query_params().get('ImageDPI')

	def set_ImageDPI(self, ImageDPI):  # Long
		self.add_query_param('ImageDPI', ImageDPI)
	def get_LongPicture(self): # Boolean
		return self.get_query_params().get('LongPicture')

	def set_LongPicture(self, LongPicture):  # Boolean
		self.add_query_param('LongPicture', LongPicture)
	def get_MaxSheetRow(self): # Long
		return self.get_query_params().get('MaxSheetRow')

	def set_MaxSheetRow(self, MaxSheetRow):  # Long
		self.add_query_param('MaxSheetRow', MaxSheetRow)
	def get_CredentialConfig(self): # Struct
		return self.get_query_params().get('CredentialConfig')

	def set_CredentialConfig(self, CredentialConfig):  # Struct
		self.add_query_param("CredentialConfig", json.dumps(CredentialConfig))



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data
import json

class CreateStoryRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2020-09-30', 'CreateStory','imm')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CustomLabels(self): # String
		return self.get_body_params().get('CustomLabels')

	def set_CustomLabels(self, CustomLabels):  # String
		self.add_body_params('CustomLabels', CustomLabels)
	def get_Notification(self): # Struct
		return self.get_query_params().get('Notification')

	def set_Notification(self, Notification):  # Struct
		self.add_query_param("Notification", json.dumps(Notification))
	def get_ProjectName(self): # String
		return self.get_body_params().get('ProjectName')

	def set_ProjectName(self, ProjectName):  # String
		self.add_body_params('ProjectName', ProjectName)
	def get_NotifyTopicName(self): # String
		return self.get_body_params().get('NotifyTopicName')

	def set_NotifyTopicName(self, NotifyTopicName):  # String
		self.add_body_params('NotifyTopicName', NotifyTopicName)
	def get_StoryType(self): # String
		return self.get_body_params().get('StoryType')

	def set_StoryType(self, StoryType):  # String
		self.add_body_params('StoryType', StoryType)
	def get_Tags(self): # Map
		return self.get_query_params().get('Tags')

	def set_Tags(self, Tags):  # Map
		self.add_query_param("Tags", json.dumps(Tags))
	def get_StorySubType(self): # String
		return self.get_body_params().get('StorySubType')

	def set_StorySubType(self, StorySubType):  # String
		self.add_body_params('StorySubType', StorySubType)
	def get_MinFileCount(self): # Long
		return self.get_body_params().get('MinFileCount')

	def set_MinFileCount(self, MinFileCount):  # Long
		self.add_body_params('MinFileCount', MinFileCount)
	def get_UserData(self): # String
		return self.get_query_params().get('UserData')

	def set_UserData(self, UserData):  # String
		self.add_query_param('UserData', UserData)
	def get_MaxFileCount(self): # Long
		return self.get_body_params().get('MaxFileCount')

	def set_MaxFileCount(self, MaxFileCount):  # Long
		self.add_body_params('MaxFileCount', MaxFileCount)
	def get_DatasetName(self): # String
		return self.get_body_params().get('DatasetName')

	def set_DatasetName(self, DatasetName):  # String
		self.add_body_params('DatasetName', DatasetName)
	def get_StoryStartTime(self): # String
		return self.get_body_params().get('StoryStartTime')

	def set_StoryStartTime(self, StoryStartTime):  # String
		self.add_body_params('StoryStartTime', StoryStartTime)
	def get_Address(self): # Struct
		return self.get_body_params().get('Address')

	def set_Address(self, Address):  # Struct
		self.add_body_params("Address", json.dumps(Address))
	def get_CustomId(self): # String
		return self.get_body_params().get('CustomId')

	def set_CustomId(self, CustomId):  # String
		self.add_body_params('CustomId', CustomId)
	def get_StoryEndTime(self): # String
		return self.get_body_params().get('StoryEndTime')

	def set_StoryEndTime(self, StoryEndTime):  # String
		self.add_body_params('StoryEndTime', StoryEndTime)
	def get_ObjectId(self): # String
		return self.get_body_params().get('ObjectId')

	def set_ObjectId(self, ObjectId):  # String
		self.add_body_params('ObjectId', ObjectId)
	def get_StoryName(self): # String
		return self.get_body_params().get('StoryName')

	def set_StoryName(self, StoryName):  # String
		self.add_body_params('StoryName', StoryName)
